@@ -420,6 +420,7 @@ void AutoCorrectionTest::shouldNotUpperCaseFirstCharOfSentence()
     QCOMPARE(doc.toPlainText(), result);
 
 }
+
 typedef QHash<QString, QString> mapAutoCorrect;
 Q_DECLARE_METATYPE(mapAutoCorrect)
 
@@ -449,12 +450,10 @@ void AutoCorrectionTest::shouldAutocorrectMultiWord_data()
     map.insert(QStringLiteral("a boo"), QStringLiteral("b bla"));
     QTest::newRow("multiword-2 with uppercase") << QStringLiteral("toto. A boo") << QStringLiteral("toto. B bla") << map;
 
-
     map.clear();
     map.insert(QStringLiteral("a boo1111111111"), QStringLiteral("b bla"));
     QTest::newRow("multiword-3") << QStringLiteral("a boo") << QStringLiteral("a boo") << map;
 
-
     map.clear();
     map.insert(QStringLiteral("boo"), QStringLiteral("Bla"));
     QTest::newRow("withuppercase") << QStringLiteral("Boo") << QStringLiteral("Bla") << map;
@@ -471,7 +470,6 @@ void AutoCorrectionTest::shouldAutocorrectMultiWord_data()
     map.insert(QStringLiteral("boo"), QStringLiteral("Bla"));
     QTest::newRow("withuppercase-4") << QStringLiteral("boo") << QStringLiteral("bla") << map;
 
-
     map.clear();
     map.insert(QStringLiteral("booooo"), QStringLiteral("bla"));
     QTest::newRow("nofindtext") << QStringLiteral("boo") << QStringLiteral("boo") << map;
@@ -490,7 +488,6 @@ void AutoCorrectionTest::shouldAutocorrectMultiWord_data()
     map.insert(QStringLiteral("boo"), QStringLiteral("bla"));
     QTest::newRow("dontreplaceinpieceofword") << QStringLiteral("voitureboo") << QStringLiteral("voitureboo") << map;
 
-
     map.clear();
     map.insert(QStringLiteral("boo"), QStringLiteral("bla"));
     map.insert(QStringLiteral("booOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo"), QStringLiteral("bla"));
@@ -515,13 +512,160 @@ void AutoCorrectionTest::shouldAutocorrectMultiWord()
     QCOMPARE(doc.toPlainText(), convertedString);
 }
 
+void AutoCorrectionTest::shouldAddNonBreakingSpace_data()
+{
+    QTest::addColumn<QString>("originalString");
+    QTest::addColumn<QString>("convertedString");
+    QTest::addColumn<QString>("language");
+    QTest::addColumn<bool>("enableAddNonBreakingSpace");
+    QTest::newRow("convert1") << QStringLiteral("boo !") << QStringLiteral("boob!") << QStringLiteral("fr") << true;
+    QTest::newRow("disable") << QStringLiteral("boo !") << QStringLiteral("boo !") << QStringLiteral("fr") << false;
+    QTest::newRow("nonchanges") << QStringLiteral("boo") << QStringLiteral("boo") << QStringLiteral("fr") << true;
+    QTest::newRow("convert2") << QStringLiteral("boo ;") << QStringLiteral("boob;") << QStringLiteral("fr") << true;
+    QTest::newRow("convert3") << QStringLiteral("boo ?") << QStringLiteral("boob?") << QStringLiteral("fr") << true;
+    QTest::newRow("convert4") << QStringLiteral("boo :") << QStringLiteral("boob:") << QStringLiteral("fr") << true;
+    QTest::newRow("nonfrenchlanguage") << QStringLiteral("boo :") << QStringLiteral("boo :") << QStringLiteral("ge") << true;
+    QTest::newRow("onecharacter") << QStringLiteral(":") << QStringLiteral(":") << QStringLiteral("fr") << true;
+    QTest::newRow("onecharacter2") << QStringLiteral(" ") << QStringLiteral(" ") << QStringLiteral("fr") << true;
+    QTest::newRow("percentage") << QStringLiteral("50 %") << QStringLiteral("50b%") << QStringLiteral("fr") << true;
+    QTest::newRow("degres") << QStringLiteral("50 °C") << QStringLiteral("50b°C") << QStringLiteral("fr") << true;
+    QTest::newRow("simplespace") << QStringLiteral(" ") << QStringLiteral(" ") << QStringLiteral("fr") << true;
+}
+
 void AutoCorrectionTest::shouldAddNonBreakingSpace()
+{
+    QFETCH(QString, originalString);
+    QFETCH(QString, convertedString);
+    QFETCH(QString, language);
+    QFETCH(bool, enableAddNonBreakingSpace);
+
+    PimCommon::AutoCorrection autocorrection;
+    autocorrection.setEnabledAutoCorrection(true);
+    autocorrection.setAddNonBreakingSpace(enableAddNonBreakingSpace);
+    autocorrection.setLanguage(language);
+    autocorrection.setNonBreakingSpace(QChar(QLatin1Char('b')));
+
+    QTextDocument doc;
+    doc.setPlainText(originalString);
+    int position = originalString.length();
+    autocorrection.autocorrect(false, doc, position);
+    QCOMPARE(doc.toPlainText(), convertedString);
+}
+
+void AutoCorrectionTest::shouldReplaceWithMultiOption_data()
+{
+    QTest::addColumn<QString>("originalString");
+    QTest::addColumn<QString>("convertedString");
+    QTest::addColumn<mapAutoCorrect>("convertStringHash");
+
+    QTest::addColumn<bool>("enable");
+    QTest::addColumn<bool>("uppercaseFirstCharOfSentence");
+    QTest::addColumn<bool>("advancedAutocorrect");
+    QTest::addColumn<bool>("fixtoouppercase");
+    mapAutoCorrect map;
+    map.insert(QStringLiteral("boo"), QStringLiteral("bla"));
+
+    QTest::newRow("disable") << QStringLiteral("Boo boo boo") << QStringLiteral("Boo boo boo") << map << false << false << false << false;
+    QTest::newRow("enablebutdisablealloptions") << QStringLiteral("Boo boo boo") << QStringLiteral("Boo boo boo") << map << true << false << false << false;
+    QTest::newRow("enableandenableuppercase") << QStringLiteral("Boo boo boo") << QStringLiteral("Boo boo boo") << map << true << true << false << false;
+    QTest::newRow("enableandenableuppercaseandadvanced") << QStringLiteral("Boo boo boo") << QStringLiteral("Boo boo bla") << map << true << true << true << false;
+
+    QTest::newRow("enableandenableuppercaseandadvanced-2") << QStringLiteral("Boo boo. boo") << QStringLiteral("Boo boo. Bla") << map << true << true << true << false;
+    QTest::newRow("enableandenableuppercaseandadvanced-3") << QStringLiteral("blablobli") << QStringLiteral("Blablobli") << map << true << true << true << false;
+    QTest::newRow("enableandenableuppercaseandadvanced-4") << QStringLiteral("blablobli. foo") << QStringLiteral("blablobli. Foo") << map << true << true << true << false;
+
+    QTest::newRow("enableandenablefixtouppercase") << QStringLiteral("Boo boo. BOo") << QStringLiteral("Boo boo. Boo") << map << true << true << false << true;
+    QTest::newRow("enableandenablefixtouppercase-2") << QStringLiteral("Boo BOo") << QStringLiteral("Boo Boo") << map << true << true << false << true;
+    //TODO add more
+}
+
+void AutoCorrectionTest::shouldReplaceWithMultiOption()
+{
+    QFETCH(QString, originalString);
+    QFETCH(QString, convertedString);
+    QFETCH(mapAutoCorrect, convertStringHash);
+    QFETCH(bool, enable);
+    QFETCH(bool, uppercaseFirstCharOfSentence);
+    QFETCH(bool, advancedAutocorrect);
+    QFETCH(bool, fixtoouppercase);
+
+    PimCommon::AutoCorrection autocorrection;
+    autocorrection.setEnabledAutoCorrection(enable);
+    autocorrection.setAdvancedAutocorrect(advancedAutocorrect);
+    autocorrection.setAutocorrectEntries(convertStringHash);
+    autocorrection.setUppercaseFirstCharOfSentence(uppercaseFirstCharOfSentence);
+    autocorrection.setFixTwoUppercaseChars(fixtoouppercase);
+
+    QTextDocument doc;
+    doc.setPlainText(originalString);
+    int position = originalString.length();
+    autocorrection.autocorrect(false, doc, position);
+    QCOMPARE(doc.toPlainText(), convertedString);
+}
+
+void AutoCorrectionTest::shouldAddNonBreakingSpaceBeforeAfterQuote()
 {
     PimCommon::AutoCorrection autocorrection;
     autocorrection.setEnabledAutoCorrection(true);
+    autocorrection.setReplaceDoubleQuotes(true);
+    autocorrection.setReplaceSingleQuotes(true);
     autocorrection.setLanguage(QStringLiteral("fr"));
     autocorrection.setAddNonBreakingSpace(true);
-    //TODO
+    //TODO fix me verify why it doesn't use no breaking space
+    const QChar nbsp = QChar(/*QChar::Nbsp*/QLatin1Char('b'));
+    autocorrection.setNonBreakingSpace(nbsp);
+
+    PimCommon::AutoCorrection::TypographicQuotes doubleQuote;
+    doubleQuote.begin = QLatin1Char('A');
+    doubleQuote.end = QLatin1Char('B');
+    autocorrection.setTypographicDoubleQuotes(doubleQuote);
+
+    PimCommon::AutoCorrection::TypographicQuotes simpleQuote;
+    simpleQuote.begin = QLatin1Char('A');
+    simpleQuote.end = QLatin1Char('B');
+
+    autocorrection.setTypographicSingleQuotes(simpleQuote);
+
+    QTextDocument doc;
+    QString text = QStringLiteral("sss");
+
+    doc.setPlainText(QLatin1Char('"') + text);
+    int position = text.length();
+    autocorrection.autocorrect(false, doc, position);
+
+    QCOMPARE(doc.toPlainText(), QString(doubleQuote.begin + nbsp + text));
+
+    text = QStringLiteral("sss");
+    doc.setPlainText(text + QStringLiteral("\""));
+    position = text.length();
+    autocorrection.autocorrect(false, doc, position);
+    QCOMPARE(doc.toPlainText(), QString(text + nbsp + doubleQuote.end));
+
+    //Simple quote
+    text = QStringLiteral("sss");
+    doc.setPlainText(text + QStringLiteral("\'"));
+    position = text.length();
+    autocorrection.autocorrect(false, doc, position);
+    QCOMPARE(doc.toPlainText(), QString(text + nbsp + simpleQuote.end));
+
+    text = QStringLiteral("sss");
+    doc.setPlainText(QStringLiteral("\"") + text + QStringLiteral("\""));
+    position = text.length();
+    autocorrection.autocorrect(false, doc, position);
+    QCOMPARE(doc.toPlainText(), QString(doubleQuote.begin + nbsp + text + nbsp + doubleQuote.end));
+
+    //Simple quote
+    text = QStringLiteral("sss");
+    doc.setPlainText(QStringLiteral("\'") + text + QStringLiteral("\'"));
+    position = text.length();
+    autocorrection.autocorrect(false, doc, position);
+    QCOMPARE(doc.toPlainText(), QString(simpleQuote.begin + nbsp + text + nbsp + simpleQuote.end));
+
+    text = QStringLiteral("(");
+    doc.setPlainText(QStringLiteral("\"") + text + QStringLiteral("\""));
+    position = text.length();
+    autocorrection.autocorrect(false, doc, position);
+    QCOMPARE(doc.toPlainText(), QString(doubleQuote.begin + nbsp + text + nbsp + doubleQuote.end));
 }
 
 QTEST_MAIN(AutoCorrectionTest)
