@@ -18,10 +18,10 @@
 #ifndef STORAGEAUTHWEBVIEW_H
 #define STORAGEAUTHWEBVIEW_H
 
-#include <QWebView>
+#include <QWebEngineView>
 namespace PimCommon
 {
-class StorageAuthWebView : public QWebView
+class StorageAuthWebView : public QWebEngineView
 {
     Q_OBJECT
 public:
